@@ -2,13 +2,14 @@
 import pika
 
 
-def get_channel(connection, queue_name, durable=True, confirm_delivery=True, is_delay=False):
+def get_channel(connection, queue_name, durable=True, confirm_delivery=True, is_delay=False, is_lazy=True):
     """ Init method to return a prepared channel for consuming
     """
     channel = connection.channel()
-    channel.queue_declare(queue=queue_name, durable=durable, arguments={
-        'x-max-priority': 255
-    })
+    args = {'x-max-priority': 255}
+    if is_lazy:
+        args['x-queue-mode'] = 'lazy'
+    channel.queue_declare(queue=queue_name, durable=durable, arguments=args)
     if confirm_delivery:
         channel.confirm_delivery()
 
