@@ -9,7 +9,8 @@ class RabbitSpider(scrapy.Spider):
     def _make_request(self, mframe, hframe, body):
 
         data = json.loads(body,encoding="utf-8")
-        data['params']['pyppeteer'] = True
+        if self.settings.get("PYPPETEER_ENABLE"):
+            data['params']['pyppeteer'] = self.settings.get("PYPPETEER_ENABLE")
         request = scrapy.Request(data['url'], callback=self.parse, dont_filter=True,meta=data['params'])
 
         return request
